package bus_service

import (
	"context"
	"errors"
	"github.com/go-admin-team/go-admin-core/sdk/service"
	"go-admin/app/admin/models/bus_models"
)

type ProductService struct {
	service.Service
}

// GetProductList 获取产品列表
func (e *ProductService) GetProductList(ctx context.Context, req bus_models.ProductListReq) (bus_models.ProductListResp, error) {
	var products []bus_models.BusProduct
	var resp bus_models.ProductListResp

	// 构建查询条件，假设我们支持根据 product_code 查询
	db := e.Orm.WithContext(ctx)

	// 如果需要支持分页，可以根据请求条件调整查询
	if req.ProductCode != "" {
		db = db.Where("product_code = ?", req.ProductCode)
	}
	if req.ProductName != "" {
		db = db.Where("product_name LIKE ?", "%"+req.ProductName+"%")
	}
	if req.ProductType != 0 {
		db = db.Where("product_type = ?", req.ProductType)
	}

	// 查询数据库
	if err := db.Find(&products).Error; err != nil {
		return resp, errors.New("查询产品列表失败")
	}

	resp.List = products
	resp.Total = len(products)

	return resp, nil
}

// CreateProduct 新建产品
func (e *ProductService) CreateProduct(req bus_models.CreateProductReq) (bus_models.CreateProductResp, error) {
	var resp bus_models.CreateProductResp
	product := bus_models.BusProduct{
		ProductCode: req.ProductCode,
		ProductName: req.ProductName,
		ProductType: req.ProductType,
		Platform:    req.Platform,
		Price:       req.Price,
		Discount:    req.Discount,
		RetailPrice: req.RetailPrice,
		Province:    req.Province,
		City:        req.City,
	}

	// 将产品插入数据库
	if err := e.Orm.Create(&product).Error; err != nil {
		return resp, errors.New("创建产品失败")
	}

	// 返回创建成功的响应
	resp.ID = product.ID

	return resp, nil
}

// EditProduct 编辑产品
func (e *ProductService) EditProduct(req bus_models.EditProductReq) error {
	product := bus_models.BusProduct{
		ProductCode: req.ProductCode,
		ProductName: req.ProductName,
		ProductType: req.ProductType,
		Platform:    req.Platform,
		Price:       req.Price,
		Discount:    req.Discount,
		RetailPrice: req.RetailPrice,
		Province:    req.Province,
		City:        req.City,
	}

	// 更新产品信息
	if err := e.Orm.Model(&bus_models.BusProduct{}).Where("product_code = ?", req.ProductCode).
		Updates(&product).Error; err != nil {
		return errors.New("编辑产品失败")
	}

	return nil
}

// DeleteProduct 删除产品
func (e *ProductService) DeleteProduct(req bus_models.DeleteProductReq) error {
	// 执行删除操作
	if err := e.Orm.Where("id = ?", req.ID).Delete(&bus_models.BusProduct{}).Error; err != nil {
		return errors.New("删除产品失败")
	}

	return nil
}
